@@ -34,7 +34,7 @@
 #define _GLIBCXX_RELEASE 11
 
 // The datestamp of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20220421
+#define __GLIBCXX__ 20230528
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -1092,6 +1092,9 @@ namespace std
 /* Define if readlink is available in <unistd.h>. */
 /* #undef _GLIBCXX_HAVE_READLINK */
 
+/* Define to 1 if you have the `secure_getenv' function. */
+/* #undef _GLIBCXX_HAVE_SECURE_GETENV */
+
 /* Define to 1 if you have the `setenv' function. */
 /* #undef _GLIBCXX_HAVE_SETENV */
 
@@ -1653,7 +1656,7 @@ namespace std
 
 /* Define if C11 functions in <uchar.h> should be imported into namespace std
    in <cuchar>. */
-#define _GLIBCXX_USE_C11_UCHAR_CXX11 1
+/* #undef _GLIBCXX_USE_C11_UCHAR_CXX11 */
 
 /* Define if C99 functions or macros from <wchar.h>, <math.h>, <complex.h>,
    <stdio.h>, and <stdlib.h> can be used or exposed. */
